{% extends "admin/change_form_object_tools.html" %}

{% block object-tools-items %}
{% for changeform_tool in changeform_tools %}
  <li>{{ changeform_tool }}</li>
{% endfor %}
{{ block.super }}
{% endblock %}
